@@ -5,13 +5,14 @@ import (
 	"strconv"
 	"strings"
 
+	log "github.com/sirupsen/logrus"
+	"github.com/spf13/cobra"
+
 	"github.com/infracost/infracost/internal/apiclient"
 	"github.com/infracost/infracost/internal/comment"
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/output"
 	"github.com/infracost/infracost/internal/ui"
-	log "github.com/sirupsen/logrus"
-	"github.com/spf13/cobra"
 )
 
 var validCommentBitbucketBehaviors = []string{"update", "new", "delete-and-new"}
@@ -82,8 +83,13 @@ func commentBitbucketCmd(ctx *config.RunContext) *cobra.Command {
 				IncludeFeedbackLink: true,
 				BasicSyntax:         true,
 			})
+			var policyFailure output.PolicyCheckFailures
 			if err != nil {
-				return err
+				if v, ok := err.(output.PolicyCheckFailures); ok {
+					policyFailure = v
+				} else {
+					return err
+				}
 			}
 
 			dryRun, _ := cmd.Flags().GetBool("dry-run")
@@ -105,6 +111,10 @@ func commentBitbucketCmd(ctx *config.RunContext) *cobra.Command {
 				cmd.Println("Comment not posted to Bitbucket (--dry-run was specified)")
 			}
 
+			if policyFailure != nil {
+				return policyFailure
+			}
+
 			return nil
 		},
 	}
