@@ -98,10 +98,10 @@ func runCompare(cmd *cobra.Command, ctx *config.RunContext, current output.Root)
 
 	format, _ := cmd.Flags().GetString("format")
 	b, err := output.FormatOutput(strings.ToLower(format), combined, output.Options{
-		DashboardEnabled: ctx.Config.IsCloudEnabled(),
-		ShowSkipped:      ctx.Config.ShowSkipped,
-		NoColor:          ctx.Config.NoColor,
-		Fields:           ctx.Config.Fields,
+		DashboardEndpoint: ctx.Config.DashboardEndpoint,
+		ShowSkipped:       ctx.Config.ShowSkipped,
+		NoColor:           ctx.Config.NoColor,
+		Fields:            ctx.Config.Fields,
 	})
 	if err != nil {
 		return err
