@@ -69,7 +69,7 @@ type Config struct {
 	DashboardAPIEndpoint      string `yaml:"dashboard_api_endpoint,omitempty" envconfig:"INFRACOST_DASHBOARD_API_ENDPOINT"`
 	DashboardEndpoint         string `yaml:"dashboard_endpoint,omitempty" envconfig:"INFRACOST_DASHBOARD_ENDPOINT"`
 	EnableDashboard           bool   `yaml:"enable_dashboard,omitempty" envconfig:"INFRACOST_ENABLE_DASHBOARD"`
-	EnableCloud               bool   `yaml:"enable_cloud,omitempty" envconfig:"INFRACOST_ENABLE_CLOUD"`
+	EnableCloud               *bool  `yaml:"enable_cloud,omitempty" envconfig:"INFRACOST_ENABLE_CLOUD"`
 	DisableHCLParsing         bool   `yaml:"disable_hcl_parsing,omitempty" envconfig:"INFRACOST_DISABLE_HCL_PARSING"`
 
 	TLSInsecureSkipVerify *bool  `envconfig:"INFRACOST_TLS_INSECURE_SKIP_VERIFY"`
@@ -77,6 +77,9 @@ type Config struct {
 
 	Currency string `envconfig:"INFRACOST_CURRENCY"`
 
+	// Org settings
+	EnableCloudForComment bool
+
 	Projects      []*Project `yaml:"projects" ignored:"true"`
 	Format        string     `yaml:"format,omitempty" ignored:"true"`
 	ShowSkipped   bool       `yaml:"show_skipped,omitempty" ignored:"true"`
@@ -225,10 +228,6 @@ func (c *Config) IsSelfHosted() bool {
 	return c.PricingAPIEndpoint != "" && c.PricingAPIEndpoint != c.DefaultPricingAPIEndpoint
 }
 
-func (c *Config) IsCloudEnabled() bool {
-	return c.EnableCloud || c.EnableDashboard
-}
-
 func IsTest() bool {
 	return os.Getenv("INFRACOST_ENV") == "test" || strings.HasSuffix(os.Args[0], ".test")
 }
