@@ -9,8 +9,13 @@ import (
 	"net/url"
 	"regexp"
 	"strings"
+	"time"
 
 	goversion "github.com/hashicorp/go-version"
+	svchost "github.com/hashicorp/terraform-svchost"
+	"github.com/hashicorp/terraform-svchost/auth"
+	"github.com/hashicorp/terraform-svchost/disco"
+	log "github.com/sirupsen/logrus"
 )
 
 var defaultRegistryHost = "registry.terraform.io"
@@ -18,23 +23,133 @@ var defaultRegistryHost = "registry.terraform.io"
 // validRegistryName is a regexp that matches valid registry identifier for namespaces, module names and targets
 var validRegistryName = regexp.MustCompile("^[0-9A-Za-z-_]+$")
 
+// The service ID used by Terraform Registry for discovering the module URLs
+var moduleServiceID = "modules.v1"
+
 // RegistryLookupResult is returned when looking up the module to check if it exists in the registry
 // and has a matching version
 type RegistryLookupResult struct {
-	Source      string
-	Version     string
-	DownloadURL string
+	OK        bool
+	ModuleURL RegistryURL
+	Version   string
+}
+
+// RegistryURL contains given URL information for a module source. This can be used to build http requests to
+// download the module or check versions of the module.
+type RegistryURL struct {
+	RawSource   string
+	Host        string
+	Location    string
+	Credentials auth.HostCredentials
+}
+
+// Disco allows discovery on given hostnames. It tries to resolve a module source based on a set of
+// discovery rules. It caches the results by hostname to avoid repeated requests for the same information.
+// Therefore, it is advisable to use Disco per project and pass it to all required clients.
+type Disco struct {
+	disco *disco.Disco
+}
+
+// NewDisco returns a Disco with the provided credentialsSource initialising the underlying Terraform Disco.
+// If Credentials are nil then all registry requests will be unauthed.
+func NewDisco(credentialsSource auth.CredentialsSource) Disco {
+	return Disco{disco: disco.NewWithCredentialsSource(credentialsSource)}
+}
+
+// ModuleLocation performs a discovery lookup for the given source and returns a RegistryURL with the real
+// url of the module source and any required Credential information. It returns false if the module location
+// is not recognised as a registry module.
+func (d Disco) ModuleLocation(source string) (RegistryURL, bool, error) {
+	// So we expect them to only have 3 or 4 parts depending on if they explicitly specify the registry
+	parts := strings.Split(source, "/")
+	if len(parts) != 4 {
+		return RegistryURL{}, false, fmt.Errorf("registry module source %s is not in the correct format", source)
+	}
+
+	host, namespace, moduleName, target := parts[0], parts[1], parts[2], parts[3]
+
+	serviceURL, err := d.disco.DiscoverServiceURL(svchost.Hostname(host), moduleServiceID)
+	if err != nil {
+		return RegistryURL{}, false, fmt.Errorf("unable to discover registry service using host %s %w", host, err)
+	}
+
+	r := RegistryURL{
+		Host:      host,
+		Location:  fmt.Sprintf("%s%s/%s/%s", serviceURL.String(), namespace, moduleName, target),
+		RawSource: source,
+	}
+
+	c, err := d.disco.CredentialsForHost(svchost.Hostname(host))
+	if err != nil {
+		return r, true, fmt.Errorf("unable to retrieve credentials for registry host %s %w", host, err)
+	}
+
+	r.Credentials = c
+	return r, true, nil
+}
+
+func (d Disco) DownloadLocation(moduleURL RegistryURL, version string) (string, error) {
+	serviceURL, err := d.disco.DiscoverServiceURL(svchost.Hostname(moduleURL.Host), moduleServiceID)
+	if err != nil {
+		return "", fmt.Errorf("unable to discover registry service using host %s %w", moduleURL.Host, err)
+	}
+
+	var u *url.URL
+	if version == "" {
+		u, err = url.Parse(fmt.Sprintf("%s/download", moduleURL.Location))
+	} else {
+		u, err = url.Parse(fmt.Sprintf("%s/%s/download", moduleURL.Location, version))
+	}
+	if err != nil {
+		return "", fmt.Errorf("error constructing download URL: %w", err)
+	}
+
+	downloadURL := serviceURL.ResolveReference(u)
+
+	log.Debugf("Looking up download URL for module %s from registry URL %s", moduleURL.RawSource, downloadURL.String())
+
+	httpClient := &http.Client{
+		Timeout: time.Second * 30,
+	}
+	req, _ := http.NewRequest("GET", downloadURL.String(), nil)
+	moduleURL.Credentials.PrepareRequest(req)
+	resp, err := httpClient.Do(req)
+
+	if err != nil {
+		return "", fmt.Errorf("error fetching download URL '%s': %w", downloadURL.String(), err)
+	}
+	defer resp.Body.Close()
+
+	location := resp.Header.Get("X-Terraform-Get")
+	if location == "" {
+		return "", fmt.Errorf("download URL has no X-Terraform-Get header")
+	}
+
+	if strings.HasPrefix(location, "/") || strings.HasPrefix(location, "./") || strings.HasPrefix(location, "../") {
+		log.Debugf("Detected relative path for location returned by download URL %s", downloadURL.String())
+
+		locationURL, err := url.Parse(location)
+		if err != nil {
+			return "", fmt.Errorf("error parsing location URL: %w", err)
+		}
+		locationURL = serviceURL.ResolveReference(locationURL)
+		location = locationURL.String()
+	}
+
+	return location, nil
 }
 
 // RegistryLoader is a loader that can lookup modules from a Terraform Registry and download them to the given destination
 type RegistryLoader struct {
 	packageFetcher *PackageFetcher
+	disco          Disco
 }
 
 // NewRegistryLoader constructs a registry loader
-func NewRegistryLoader(packageFetcher *PackageFetcher) *RegistryLoader {
+func NewRegistryLoader(packageFetcher *PackageFetcher, disco Disco) *RegistryLoader {
 	return &RegistryLoader{
 		packageFetcher: packageFetcher,
+		disco:          disco,
 	}
 }
 
@@ -43,21 +158,24 @@ func NewRegistryLoader(packageFetcher *PackageFetcher) *RegistryLoader {
 func (r *RegistryLoader) lookupModule(moduleAddr string, versionConstraints string) (*RegistryLookupResult, error) {
 	registrySource, err := normalizeRegistrySource(moduleAddr)
 	if err != nil {
-		return nil, err
+		log.Debugf("module '%s' not detected as registry module: %s", moduleAddr, err)
+		return &RegistryLookupResult{
+			OK: false,
+		}, nil
 	}
 
-	// Modules are in the format (registry)/namspace/module/target
-	// So we expect them to only have 3 or 4 parts depending on if they explicitly specify the registry
-	parts := strings.Split(registrySource, "/")
-	if len(parts) != 4 {
-		return nil, errors.New("Registry module source is not in the correct format")
+	moduleURL, ok, err := r.disco.ModuleLocation(registrySource)
+	if !ok {
+		if err != nil {
+			log.Debugf("module '%s' not detected as registry module: %s", moduleAddr, err)
+		}
+		return &RegistryLookupResult{
+			OK: false,
+		}, nil
+	}
+	if err != nil {
+		return nil, fmt.Errorf("failed to load remote module from given source %s and version constraints %s %w", moduleAddr, versionConstraints, err)
 	}
-
-	host, namespace, moduleName, target := parts[0], parts[1], parts[2], parts[3]
-
-	// By this stage we are more confident that the module source is a valid registry module
-	// We now need to check the registry to see if the module exists and if it has a version
-	moduleURL := fmt.Sprintf("https://%s/v1/modules/%s/%s/%s", host, namespace, moduleName, target)
 
 	versions, err := r.fetchModuleVersions(moduleURL)
 	if err != nil {
@@ -74,16 +192,19 @@ func (r *RegistryLoader) lookupModule(moduleAddr string, versionConstraints stri
 	}
 
 	return &RegistryLookupResult{
-		Source:      fmt.Sprintf("%s/%s/%s/%s", host, namespace, moduleName, target),
-		Version:     matchingVersion,
-		DownloadURL: fmt.Sprintf("%s/%s/download", moduleURL, matchingVersion),
+		OK:        true,
+		ModuleURL: moduleURL,
+		Version:   matchingVersion,
 	}, nil
 }
 
 // fetchModuleVersions fetches the list of versions from the registry endpoint for the given module URL
-func (r *RegistryLoader) fetchModuleVersions(moduleURL string) ([]string, error) {
+func (r *RegistryLoader) fetchModuleVersions(moduleURL RegistryURL) ([]string, error) {
 	httpClient := &http.Client{}
-	resp, err := httpClient.Get(moduleURL + "/versions")
+	req, _ := http.NewRequest("GET", moduleURL.Location+"/versions", nil)
+	moduleURL.Credentials.PrepareRequest(req)
+	resp, err := httpClient.Do(req)
+
 	if err != nil {
 		return nil, fmt.Errorf("Failed to fetch registry module versions: %w", err)
 	}
@@ -126,20 +247,15 @@ func (r *RegistryLoader) fetchModuleVersions(moduleURL string) ([]string, error)
 
 // downloadModule downloads the module to the loader's destination
 // It first calls the download URL to get the X-Terraform-Get header which contains a source we can use with go-getter to download the module
-func (r *RegistryLoader) downloadModule(downloadURL string, dest string) error {
-	httpClient := &http.Client{}
-	resp, err := httpClient.Get(downloadURL)
+func (r *RegistryLoader) downloadModule(lookupResult *RegistryLookupResult, dest string) error {
+	downloadURL, err := r.disco.DownloadLocation(lookupResult.ModuleURL, lookupResult.Version)
 	if err != nil {
-		return fmt.Errorf("Failed to download registry module: %w", err)
+		return fmt.Errorf("could not find download location: %w", err)
 	}
-	defer resp.Body.Close()
+	// Deliberately not logging the download URL since it contains a token
+	log.Debugf("Downloading module %s", lookupResult.ModuleURL.RawSource)
 
-	source := resp.Header.Get("X-Terraform-Get")
-	if source == "" {
-		return errors.New("download URL has no X-Terraform-Get header")
-	}
-
-	return r.packageFetcher.fetch(source, dest)
+	return r.packageFetcher.fetch(downloadURL, dest)
 }
 
 // findLatestMatchingVersion returns the latest version from a list of versions that matches the given constraint.
