@@ -17,18 +17,40 @@ import (
 	"github.com/infracost/infracost/internal/schema"
 )
 
-var minOutputVersion = "0.2"
-var maxOutputVersion = "0.2"
+var (
+	minOutputVersion = "0.2"
+	maxOutputVersion = "0.2"
+)
 
 type ReportInput struct {
 	Metadata map[string]string
 	Root     Root
 }
 
-func Load(data []byte) (Root, error) {
+// Load reads the file at the location p and the file body into a Root struct. Load naively
+// validates that the Infracost JSON body is valid by checking the that the version attribute is within a supported range.
+func Load(p string) (Root, error) {
 	var out Root
-	err := json.Unmarshal(data, &out)
-	return out, err
+	_, err := os.Stat(p)
+	if errors.Is(err, os.ErrNotExist) {
+		return out, errors.New("Infracost JSON file does not exist")
+	}
+
+	data, err := os.ReadFile(p)
+	if err != nil {
+		return out, fmt.Errorf("error reading Infracost JSON file %w", err)
+	}
+
+	err = json.Unmarshal(data, &out)
+	if err != nil {
+		return out, fmt.Errorf("invalid Infracost JSON file %w", err)
+	}
+
+	if !checkOutputVersion(out.Version) {
+		return out, fmt.Errorf("invalid Infracost JSON file version. Supported versions are %s ≤ x ≤ %s", minOutputVersion, maxOutputVersion)
+	}
+
+	return out, nil
 }
 
 func LoadPaths(paths []string) ([]ReportInput, error) {
@@ -62,25 +84,16 @@ func LoadPaths(paths []string) ([]ReportInput, error) {
 	inputs := make([]ReportInput, 0, len(inputFiles))
 
 	for _, f := range inputFiles {
-		data, err := os.ReadFile(f)
+		r, err := Load(f)
 		if err != nil {
-			return nil, errors.Wrap(err, "Error reading JSON file")
-		}
-
-		j, err := Load(data)
-		if err != nil {
-			return nil, errors.Wrap(err, "Error parsing JSON file")
-		}
-
-		if !checkOutputVersion(j.Version) {
-			return nil, fmt.Errorf("Invalid Infracost JSON file version. Supported versions are %s ≤ x ≤ %s", minOutputVersion, maxOutputVersion)
+			return nil, fmt.Errorf("could not load input file %s err: %w", f, err)
 		}
 
 		inputs = append(inputs, ReportInput{
 			Metadata: map[string]string{
 				"filename": f,
 			},
-			Root: j,
+			Root: r,
 		})
 	}
 
@@ -94,11 +107,11 @@ func LoadPaths(paths []string) ([]ReportInput, error) {
 func CompareTo(current, prior Root) (Root, error) {
 	priorProjects := make(map[string]*schema.Project)
 	for _, p := range prior.Projects {
-		if _, ok := priorProjects[p.Name]; ok {
-			return Root{}, fmt.Errorf("Invalid --compare-to Infracost JSON, found duplicate project name %s", p.Name)
+		if _, ok := priorProjects[p.LabelWithMetadata()]; ok {
+			return Root{}, fmt.Errorf("Invalid --compare-to Infracost JSON, found duplicate project name %s", p.LabelWithMetadata())
 		}
 
-		priorProjects[p.Name] = p.ToSchemaProject()
+		priorProjects[p.LabelWithMetadata()] = p.ToSchemaProject()
 	}
 
 	var schemaProjects schema.Projects
@@ -108,10 +121,10 @@ func CompareTo(current, prior Root) (Root, error) {
 		scp.PastResources = nil
 		scp.HasDiff = true
 
-		if v, ok := priorProjects[p.Name]; ok {
+		if v, ok := priorProjects[p.LabelWithMetadata()]; ok {
 			scp.PastResources = v.Resources
 			scp.Diff = schema.CalculateDiff(scp.PastResources, scp.Resources)
-			delete(priorProjects, p.Name)
+			delete(priorProjects, p.LabelWithMetadata())
 		}
 
 		schemaProjects = append(schemaProjects, scp)
@@ -216,7 +229,7 @@ func Combine(inputs []ReportInput) (Root, error) {
 	combined.PastTotalMonthlyCost = pastTotalMonthlyCost
 	combined.DiffTotalHourlyCost = diffTotalHourlyCost
 	combined.DiffTotalMonthlyCost = diffTotalMonthlyCost
-	combined.TimeGenerated = time.Now()
+	combined.TimeGenerated = time.Now().UTC()
 	combined.Summary = MergeSummaries(summaries)
 
 	return combined, nil
@@ -245,3 +258,32 @@ func checkOutputVersion(v string) bool {
 	}
 	return semver.Compare(v, "v"+minOutputVersion) >= 0 && semver.Compare(v, "v"+maxOutputVersion) <= 0
 }
+
+// FormatOutput returns Root r as the format specified. The default format is a table output.
+func FormatOutput(format string, r Root, opts Options) ([]byte, error) {
+	var b []byte
+	var err error
+
+	switch format {
+	case "json":
+		b, err = ToJSON(r, opts)
+	case "html":
+		b, err = ToHTML(r, opts)
+	case "diff":
+		b, err = ToDiff(r, opts)
+	case "github-comment", "gitlab-comment", "azure-repos-comment":
+		b, err = ToMarkdown(r, opts, MarkdownOptions{})
+	case "bitbucket-comment":
+		b, err = ToMarkdown(r, opts, MarkdownOptions{BasicSyntax: true})
+	case "slack-message":
+		b, err = ToSlackMessage(r, opts)
+	default:
+		b, err = ToTable(r, opts)
+	}
+
+	if err != nil {
+		return nil, fmt.Errorf("error generating %s output %w", format, err)
+	}
+
+	return b, nil
+}
