@@ -103,6 +103,8 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getDirectoryServiceDirectory(),
 	getTransferServerRegistryItem(),
 	getNetworkfirewallFirewallRegistryItem(),
+	getGlobalAcceleratorRegistryItem(),
+	getGlobalacceleratorEndpointGroupRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
@@ -244,6 +246,9 @@ var FreeResources = []string{
 	"aws_elasticache_security_group",
 	"aws_elasticache_subnet_group",
 
+	// "AWS Global Accelerator Listener
+	"aws_globalaccelerator_listener",
+
 	// AWS Glue
 	"aws_glue_catalog_table",
 	"aws_glue_classifier",
