@@ -4,8 +4,8 @@ import "github.com/infracost/infracost/internal/schema"
 
 // ResourceRegistry grouped alphabetically
 var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
-	GetAzureRMActiveDirectoryDomainServiceRegistryItem(),
-	GetAzureRMActiveDirectoryDomainServiceReplicaSetRegistryItem(),
+	getActiveDirectoryDomainServiceRegistryItem(),
+	getActiveDirectoryDomainServiceReplicaSetRegistryItem(),
 	getAPIManagementRegistryItem(),
 	GetAzureRMApplicationGatewayRegistryItem(),
 	getAppServiceEnvironmentRegistryItem(),
@@ -14,8 +14,8 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMAppNATGatewayRegistryItem(),
 	getAppServiceCertificateBindingRegistryItem(),
 	getAppServiceCertificateOrderRegistryItem(),
-	GetAzureRMAppServiceCustomHostnameBindingRegistryItem(),
-	GetAzureRMAppServicePlanRegistryItem(),
+	getAppServiceCustomHostnameBindingRegistryItem(),
+	getAppServicePlanRegistryItem(),
 	getApplicationInsightsWebTestRegistryItem(),
 	getApplicationInsightsRegistryItem(),
 	getAutomationAccountRegistryItem(),
@@ -24,7 +24,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getAutomationJobScheduleRegistryItem(),
 	GetAzureRMBastionHostRegistryItem(),
 	GetAzureRMCDNEndpointRegistryItem(),
-	GetAzureRMContainerRegistryRegistryItem(),
+	getContainerRegistryRegistryItem(),
 	GetAzureRMCosmosdbCassandraKeyspaceRegistryItem(),
 	GetAzureRMCosmosdbCassandraTableRegistryItem(),
 	GetAzureRMCosmosdbGremlinDatabaseRegistryItem(),
@@ -34,16 +34,16 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMCosmosdbSQLContainerRegistryItem(),
 	GetAzureRMCosmosdbSQLDatabaseRegistryItem(),
 	GetAzureRMCosmosdbTableRegistryItem(),
-	GetAzureRMDatabricksWorkspaceRegistryItem(),
-	GetAzureRMDNSaRecordRegistryItem(),
-	GetAzureRMDNSaaaaRecordRegistryItem(),
-	GetAzureRMDNScaaRecordRegistryItem(),
-	GetAzureRMDNScnameRecordRegistryItem(),
-	GetAzureRMDNSmxRecordRegistryItem(),
-	GetAzureRMDNSnsRecordRegistryItem(),
-	GetAzureRMDNSptrRecordRegistryItem(),
-	GetAzureRMDNSsrvRecordRegistryItem(),
-	GetAzureRMDNStxtRecordRegistryItem(),
+	getDatabricksWorkspaceRegistryItem(),
+	getDNSARecordRegistryItem(),
+	getDNSAAAARecordRegistryItem(),
+	getDNSCAARecordRegistryItem(),
+	getDNSCNameRecordRegistryItem(),
+	getDNSMXRecordRegistryItem(),
+	getDNSNSRecordRegistryItem(),
+	getDNSPtrRecordRegistryItem(),
+	getDNSSrvRecordRegistryItem(),
+	getDNSTxtRecordRegistryItem(),
 	GetAzureRMDNSPrivateZoneRegistryItem(),
 	GetAzureRMDNSZoneRegistryItem(),
 	GetAzureRMEventHubsNamespaceRegistryItem(),
@@ -76,13 +76,13 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getAzureRMPointToSiteVpnGatewayRegistryItem(),
 	getAzureRMPostgreSQLFlexibleServerRegistryItem(),
 	GetAzureRMPostgreSQLServerRegistryItem(),
-	GetAzureRMPrivateDNSaRecordRegistryItem(),
-	GetAzureRMPrivateDNSaaaaRecordRegistryItem(),
-	GetAzureRMPrivateDNScnameRecordRegistryItem(),
-	GetAzureRMPrivateDNSmxRecordRegistryItem(),
-	GetAzureRMPrivateDNSptrRecordRegistryItem(),
-	GetAzureRMPrivateDNSsrvRecordRegistryItem(),
-	GetAzureRMPrivateDNStxtRecordRegistryItem(),
+	getPrivateDNSARecordRegistryItem(),
+	getPrivateDNSAAAARecordRegistryItem(),
+	getPrivateDNSCNameRecordRegistryItem(),
+	getPrivateDNSMXRecordRegistryItem(),
+	getPrivateDNSPTRRecordRegistryItem(),
+	getPrivateDNSSRVRecordRegistryItem(),
+	getPrivateDNSTXTRecordRegistryItem(),
 	GetAzureRMPrivateEndpointRegistryItem(),
 	GetAzureRMPublicIPRegistryItem(),
 	GetAzureRMPublicIPPrefixRegistryItem(),
