@@ -144,7 +144,7 @@ func (p *TerragruntHCLProvider) LoadResources(usage map[string]*schema.UsageData
 			project.Metadata = config.DetectProjectMetadata(projectPath)
 			project.Metadata.Type = p.Type()
 			p.AddMetadata(project.Metadata)
-			project.Name = schema.GenerateProjectName(project.Metadata, p.ctx.ProjectConfig.Name, p.ctx.RunContext.Config.IsCloudEnabled())
+			project.Name = schema.GenerateProjectName(project.Metadata, p.ctx.ProjectConfig.Name, p.ctx.RunContext.IsCloudEnabled())
 			allProjects = append(allProjects, project)
 		}
 	}
